========
lacosmic
========

|PyPI Version| |CI Status| |Codecov Status| |Stable RTD Status| |Zenodo| |Astropy|

lacosmic is a Python package to remove cosmic rays from an
astronomical image using the `L.A.Cosmic algorithm
<http://www.astro.yale.edu/dokkum/lacosmic/>`_.  The algorithm is
based on Laplacian edge detection and is described in `van Dokkum
(2001; PASP 113, 1420)
<https://ui.adsabs.harvard.edu/abs/2001PASP..113.1420V/abstract>`_.


.. |PyPI Version| image::  https://img.shields.io/pypi/v/lacosmic.svg?logo=pypi&logoColor=white&label=PyPI
    :target: https://pypi.org/project/lacosmic/
    :alt: PyPI Latest Release

.. |Astropy| image:: https://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: https://www.astropy.org/
    :alt: Powered by Astropy

.. |CI Status| image:: https://github.com/larrybradley/lacosmic/workflows/CI%20Tests/badge.svg#
    :target: https://github.com/larrybradley/lacosmic/actions
    :alt: CI Status

.. |Codecov Status| image:: https://img.shields.io/codecov/c/github/larrybradley/lacosmic?logo=codecov
    :target: https://codecov.io/gh/larrybradley/lacosmic
    :alt: Codecov Status

.. |Stable RTD Status| image:: https://img.shields.io/readthedocs/lacosmic/latest.svg?logo=read%20the%20docs&logoColor=white&label=Docs&version=stable
    :target: https://lacosmic.readthedocs.io/en/stable/
    :alt: Stable Documentation Status

.. |Zenodo| image:: https://zenodo.org/badge/28157875.svg
    :target: https://zenodo.org/badge/latestdoi/28157875
    :alt: Zenodo Latest DOI
